@@ -26,9 +26,9 @@ import olm
 from future.moves.itertools import zip_longest
 
 from ..api import Api
+from ..event_builders import ToDeviceMessage
 from ..events import KeyVerificationEvent, KeyVerificationStart
 from ..exceptions import LocalProtocolError
-from ..event_builders import ToDeviceMessage
 from .device import OlmDevice
 
 
@@ -90,7 +90,7 @@ class Sas(olm.Sas):
     _user_cancel_error = ("m.user", "Canceled by user")
     _timeout_error = ("m.timeout", "Timed out")
     _txid_error = ("m.unknown_transaction", "Unknown transaction")
-    _unknonw_method_error = ("m.unknown_method", "Unknown method")
+    _unknown_method_error = ("m.unknown_method", "Unknown method")
     _unexpected_message_error = ("m.unexpected_message", "Unexpected message")
     _key_mismatch_error = ("m.key_mismatch", "Key mismatch")
     _user_mismatch_error = ("m.user_error", "User mismatch")
@@ -249,8 +249,8 @@ class Sas(olm.Sas):
         if (
             Sas._sas_method_v1 != event.method
             or (
-                Sas._key_agreement_v1 not in event.key_agreement_protocols and
-                Sas._key_agreement_v2 not in event.key_agreement_protocols
+                Sas._key_agreement_v1 not in event.key_agreement_protocols
+                and Sas._key_agreement_v2 not in event.key_agreement_protocols
             )
             or Sas._hash_v1 not in event.hashes
             or (
@@ -263,7 +263,7 @@ class Sas(olm.Sas):
             )
         ):
             obj.state = SasState.canceled
-            obj.cancel_code, obj.cancel_reason = obj._unknonw_method_error
+            obj.cancel_code, obj.cancel_reason = obj._unknown_method_error
 
         return obj
 
@@ -411,8 +411,7 @@ class Sas(olm.Sas):
         generated_bytes = self.generate_bytes(extra_info, 5)
         number = "".join([format(x, "08b") for x in bytes(generated_bytes)])
         return tuple(
-            int(x, 2) + 1000
-            for x in map("".join, list(self._grouper(number[:-1], 13)))
+            int(x, 2) + 1000 for x in map("".join, list(self._grouper(number[:-1], 13)))
         )
 
     def start_verification(self) -> ToDeviceMessage:
@@ -524,7 +523,7 @@ class Sas(olm.Sas):
                 "SAS verification was canceled, can't " "generate MAC."
             )
 
-        key_id = "ed25519:{}".format(self.own_device)
+        key_id = f"ed25519:{self.own_device}"
 
         assert self.chosen_mac_method
         if self.chosen_mac_method == self._mac_normal:
@@ -534,14 +533,8 @@ class Sas(olm.Sas):
 
         info = (
             "MATRIX_KEY_VERIFICATION_MAC"
-            "{first_user}{first_device}"
-            "{second_user}{second_device}{transaction_id}".format(
-                first_user=self.own_user,
-                first_device=self.own_device,
-                second_user=self.other_olm_device.user_id,
-                second_device=self.other_olm_device.id,
-                transaction_id=self.transaction_id,
-            )
+            f"{self.own_user}{self.own_device}"
+            f"{self.other_olm_device.user_id}{self.other_olm_device.id}{self.transaction_id}"
         )
 
         mac = {key_id: calculate_mac(self.own_fp_key, info + key_id)}
@@ -623,7 +616,7 @@ class Sas(olm.Sas):
             )
         ):
             self.state = SasState.canceled
-            self.cancel_code, self.cancel_reason = Sas._unknonw_method_error
+            self.cancel_code, self.cancel_reason = Sas._unknown_method_error
             return
 
         self.commitment = event.commitment
@@ -634,9 +627,9 @@ class Sas(olm.Sas):
 
     def receive_key_event(self, event):
         """Receive a KeyVerificationKey event."""
-        if (self.other_key_set or
-                ((self.state != SasState.started) and
-                 (self.state != SasState.accepted))):
+        if self.other_key_set or (
+            (self.state != SasState.started) and (self.state != SasState.accepted)
+        ):
             self.state = SasState.canceled
             (
                 self.cancel_code,
@@ -682,15 +675,8 @@ class Sas(olm.Sas):
             return
 
         info = (
-            "MATRIX_KEY_VERIFICATION_MAC"
-            "{first_user}{first_device}"
-            "{second_user}{second_device}{transaction_id}".format(
-                first_user=self.other_olm_device.user_id,
-                first_device=self.other_olm_device.id,
-                second_user=self.own_user,
-                second_device=self.own_device,
-                transaction_id=self.transaction_id,
-            )
+            f"MATRIX_KEY_VERIFICATION_MAC{self.other_olm_device.user_id}{self.other_olm_device.id}"
+            f"{self.own_user}{self.own_device}{self.transaction_id}"
         )
 
         key_ids = ",".join(sorted(event.mac.keys()))
