@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 # Copyright © 2018-2019 Damir Jelić <poljar@termina.org.uk>
+# Copyright © 2021 Famedly GmbH
 #
 # Permission to use, copy, modify, and/or distribute this software for
 # any purpose with or without fee is hereby granted, provided that the
@@ -17,14 +18,12 @@
 from __future__ import unicode_literals
 
 import time
+from dataclasses import dataclass, field
 from typing import Any, Dict, List, Optional, Union
 
-from dataclasses import dataclass, field
-
-from ..schemas import Schemas
-from .misc import (BadEventType, UnknownBadEvent, validate_or_badevent, verify,
-                   BadEvent)
 from ..event_builders import RoomKeyRequestMessage
+from ..schemas import Schemas
+from .misc import BadEvent, BadEventType, UnknownBadEvent, validate_or_badevent, verify
 
 
 @dataclass
@@ -160,6 +159,8 @@ class Event:
             return RoomEncryptionEvent.from_dict(event_dict)
         elif event_dict["type"] == "m.room.redaction":
             return RedactionEvent.from_dict(event_dict)
+        elif event_dict["type"] == "m.room.tombstone":
+            return RoomUpgradeEvent.from_dict(event_dict)
         elif event_dict["type"] == "m.room.encrypted":
             return Event.parse_encrypted_event(event_dict)
         elif event_dict["type"] == "m.sticker":
@@ -231,6 +232,7 @@ class UnknownEvent(Event):
         type (str): The type of the event.
 
     """
+
     type: str = field()
 
     @classmethod
@@ -300,6 +302,7 @@ class MegolmEvent(Event):
             our own device, otherwise None.
 
     """
+
     device_id: str = field()
     ciphertext: str = field()
     algorithm: str = field()
@@ -325,8 +328,11 @@ class MegolmEvent(Event):
         algorithm = content["algorithm"]
 
         room_id = event_dict.get("room_id", None)
-        tx_id = (event_dict["unsigned"].get("transaction_id", None)
-                 if "unsigned" in event_dict else None)
+        tx_id = (
+            event_dict["unsigned"].get("transaction_id", None)
+            if "unsigned" in event_dict
+            else None
+        )
 
         event = cls(
             event_dict,
@@ -378,7 +384,7 @@ class MegolmEvent(Event):
                 "algorithm": self.algorithm,
                 "session_id": self.session_id,
                 "room_id": self.room_id,
-                "sender_key": self.sender_key
+                "sender_key": self.sender_key,
             },
             "request_id": request_id,
             "requesting_device_id": requesting_device_id,
@@ -570,10 +576,8 @@ class RedactedEvent(Event):
     reason: Optional[str] = field()
 
     def __str__(self):
-        reason = ", reason: {}".format(self.reason) if self.reason else ""
-        return "Redacted event of type {}, by {}{}.".format(
-            self.type, self.redacter, reason
-        )
+        reason = f", reason: {self.reason}" if self.reason else ""
+        return f"Redacted event of type {self.type}, by {self.redacter}{reason}."
 
     @property
     def event_type(self):
@@ -619,6 +623,7 @@ class RoomCreateEvent(Event):
             this too much unless they want to perform room upgrades.
 
     """
+
     creator: str = field()
     federate: bool = True
     room_version: str = "1"
@@ -711,9 +716,10 @@ class RoomHistoryVisibilityEvent(Event):
 
     @classmethod
     @verify(Schemas.room_history_visibility)
-    def from_dict(cls,
-                  parsed_dict,  # type: Dict[Any, Any]
-                  ):
+    def from_dict(
+        cls,
+        parsed_dict,  # type: Dict[Any, Any]
+    ):
         # type: (...) -> Union[RoomHistoryVisibilityEvent, BadEventType]
         history_visibility = parsed_dict["content"]["history_visibility"]
 
@@ -939,7 +945,9 @@ class RoomEncryptedMedia(RoomMessage):
         thumbnail_hashes = thumbnail_file.get("hashes")
         thumbnail_iv = thumbnail_file.get("iv")
 
-        mimetype = info.get("mimetype") or parsed_dict["content"]["file"].get("mimetype")
+        mimetype = info.get("mimetype") or parsed_dict["content"]["file"].get(
+            "mimetype"
+        )
 
         return cls(
             parsed_dict,
@@ -1052,7 +1060,7 @@ class RoomMessageFormatted(RoomMessage):
 
     def __str__(self):
         # type: () -> str
-        return "{}: {}".format(self.sender, self.body)
+        return f"{self.sender}: {self.body}"
 
     @staticmethod
     def _validate(parsed_dict):
@@ -1108,7 +1116,7 @@ class RoomMessageText(RoomMessageFormatted):
 
 @dataclass
 class RoomMessageEmote(RoomMessageFormatted):
-    """A room message coresponding to the m.emote msgtype.
+    """A room message corresponding to the m.emote msgtype.
 
     This message is similar to m.text except that the sender is 'performing'
     the action contained in the body key, similar to /me in IRC.
@@ -1299,7 +1307,9 @@ class PowerLevels:
         return self.get_user_level(user_id) >= self.defaults.invite
 
     def can_user_kick(
-        self, user_id: str, target_user_id: Optional[str] = None,
+        self,
+        user_id: str,
+        target_user_id: Optional[str] = None,
     ) -> bool:
         """Return whether a user has enough power to kick another.
 
@@ -1315,7 +1325,9 @@ class PowerLevels:
         return can_kick_lower and level > self.get_user_level(target_user_id)
 
     def can_user_ban(
-        self, user_id: str, target_user_id: Optional[str] = None,
+        self,
+        user_id: str,
+        target_user_id: Optional[str] = None,
     ) -> bool:
         """Return whether a user has enough power to ban another.
 
@@ -1331,13 +1343,11 @@ class PowerLevels:
         return can_ban_lower and level > self.get_user_level(target_user_id)
 
     def can_user_redact(self, user_id: str):
-        """Return whether a user has enough power to redact other user's events.
-        """
+        """Return whether a user has enough power to redact other user's events."""
         return self.get_user_level(user_id) >= self.defaults.redact
 
     def can_user_notify(self, user_id: str, notification_type: str):
-        """Return whether user has enough power to send a type of notification.
-        """
+        """Return whether user has enough power to send a type of notification."""
         required = self.get_notification_required_level(notification_type)
         return self.get_user_level(user_id) >= required
 
@@ -1368,6 +1378,7 @@ class PowerLevelsEvent(Event):
             of the power levels of the room.
 
     """
+
     power_levels: PowerLevels = field()
 
     @classmethod
@@ -1451,9 +1462,7 @@ class RoomMemberEvent(Event):
         prev_content = unsigned.get("prev_content", None)
 
         membership = content["membership"]
-        prev_membership = (
-            prev_content.get("membership") if prev_content else None
-        )
+        prev_membership = prev_content.get("membership") if prev_content else None
 
         return cls(
             parsed_dict,
@@ -1501,3 +1510,33 @@ class StickerEvent(Event):
             url,
             content,
         )
+
+
+@dataclass
+class RoomUpgradeEvent(Event):
+    """Class representing to an m.room.tombstone event.
+
+    A state event signifying that a room has been upgraded to a
+    different room version, and that clients should go there.
+
+    Attributes:
+        body (str): A server-defined message.
+        replacement_room (str): The new room the client should be visiting.
+        content (dict): The content of the tombstone event.
+    """
+
+    body: str = field()
+    replacement_room: str = field()
+
+    @classmethod
+    @verify(Schemas.room_tombstone)
+    def from_dict(cls, parsed_dict):
+        content = parsed_dict.get("content", {})
+        body = content.get("body", "")
+        replacement_room = content.get("replacement_room", "")
+
+        return cls(
+            parsed_dict,
+            body,
+            replacement_room,
+        )
